
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'portfolio/footer', {
        apiVersion: 2,
        title: 'Footer',
        icon: 'block-default',
        category: 'pagesections',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            cta: {
                type: 'text',
                default: `Interested to work together?`,
            },
            description: {
                type: 'text',
                default: `Duis pharetra venenatis felis, ut tincidunt ipsum consequat nec. Fusce et porttitor libero, eu aliquam nisi. Nam finibus ullamcorper semper.`,
            },
            button: {
                type: 'object',
                default: {post_id: 0, url: '', title: '', 'post_type': null},
            },
            button_label: {
                type: 'text',
                default: `Get In Touch`,
            },
            site_name: {
                type: 'text',
                default: `Cody Coolhair`,
            },
            social_fb: {
                type: 'object',
                default: {post_id: 0, url: '', title: '', 'post_type': null},
            },
            social_twitter: {
                type: 'object',
                default: {post_id: 0, url: '', title: '', 'post_type': null},
            },
            social_ig: {
                type: 'object',
                default: {post_id: 0, url: '', title: '', 'post_type': null},
            },
            social_ball: {
                type: 'object',
                default: {post_id: 0, url: '', title: '', 'post_type': null},
            },
            social_behance: {
                type: 'object',
                default: {post_id: 0, url: '', title: '', 'post_type': null},
            },
            phone: {
                type: 'text',
                default: `+0 123-456-789`,
            },
            phone_link: {
                type: 'object',
                default: {post_id: 0, url: 'tel:+0 123-456-789', title: '', 'post_type': null},
            },
            email: {
                type: 'text',
                default: `info@company.com`,
            }
        },
        example: { attributes: { cta: `Interested to work together?`, description: `Duis pharetra venenatis felis, ut tincidunt ipsum consequat nec. Fusce et porttitor libero, eu aliquam nisi. Nam finibus ullamcorper semper.`, button: {post_id: 0, url: '#', title: '', 'post_type': null}, button_label: `Get In Touch`, site_name: `Cody Coolhair`, social_fb: {post_id: 0, url: '#', title: '', 'post_type': null}, social_twitter: {post_id: 0, url: '#', title: '', 'post_type': null}, social_ig: {post_id: 0, url: '#', title: '', 'post_type': null}, social_ball: {post_id: 0, url: '#', title: '', 'post_type': null}, social_behance: {post_id: 0, url: '#', title: '', 'post_type': null}, phone: `+0 123-456-789`, phone_link: {post_id: 0, url: 'tel:+0 123-456-789', title: '', 'post_type': null}, email: `info@company.com` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'bg-dark pb-5 pt-5 text-white-50' });
            const setAttributes = props.setAttributes; 
            
            
            const innerBlocksProps = null;
            
            
            return el(Fragment, {}, [
                el('footer', { ...blockProps }, el('div', { className: 'container' }, [el('div', { className: 'align-items-center gy-4 row' }, [el('div', { className: 'col-lg-8 col-md col-xl-6 me-auto' }, [el(RichText, { tagName: 'h2', className: 'fw-bold h2 mb-3 text-capitalize text-white', value: propOrDefault( props.attributes.cta, 'cta' ), onChange: function(val) { setAttributes( {cta: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'p', className: 'mb-0', value: propOrDefault( props.attributes.description, 'description' ), onChange: function(val) { setAttributes( {description: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] })]), el('div', { className: 'col-md-auto' }, props.attributes.button && props.attributes.button.url && el(RichText, { tagName: 'a', href: '#', className: 'btn btn-primary pb-2 pe-4 ps-4 pt-2', value: propOrDefault( props.attributes.button_label, 'button_label' ), onChange: function(val) { setAttributes( {button_label: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }))]), el('hr', { className: 'border-secondary mb-5 mt-5' }), el('div', { className: 'align-items-center gy-3 row' }, [el('div', { className: 'col-lg-3 col-sm-6 col-xl-4' }, el('a', { className: 'd-inline-flex fw-bold h2 lh-1 link-primary mb-0 text-decoration-none text-uppercase', href: '#' }, el(RichText, { tagName: 'span', value: propOrDefault( props.attributes.site_name, 'site_name' ), onChange: function(val) { setAttributes( {site_name: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }))), el('div', { className: 'col-lg-auto col-sm-6 order-lg-last' }, el('div', { className: 'd-inline-flex flex-wrap gap-2' }, [props.attributes.social_fb && props.attributes.social_fb.url && el('a', { href: '#', 'aria-label': 'facebook', className: 'btn btn-outline-light lh-1 p-2 rounded-circle' }, el('svg', { viewBox: '0 0 24 24', fill: 'currentColor', width: '20', height: '20' }, el('path', { d: 'M14 13.5h2.5l1-4H14v-2c0-1.03 0-2 2-2h1.5V2.14c-.326-.043-1.557-.14-2.857-.14C11.928 2 10 3.657 10 6.7v2.8H7v4h3V22h4v-8.5z' }))), props.attributes.social_twitter && props.attributes.social_twitter.url && el('a', { href: '#', 'aria-label': 'twitter', className: 'btn btn-outline-light lh-1 p-2 rounded-circle' }, el('svg', { viewBox: '0 0 24 24', fill: 'currentColor', width: '20', height: '20' }, el('path', { d: 'M22.162 5.656a8.384 8.384 0 0 1-2.402.658A4.196 4.196 0 0 0 21.6 4c-.82.488-1.719.83-2.656 1.015a4.182 4.182 0 0 0-7.126 3.814 11.874 11.874 0 0 1-8.62-4.37 4.168 4.168 0 0 0-.566 2.103c0 1.45.738 2.731 1.86 3.481a4.168 4.168 0 0 1-1.894-.523v.052a4.185 4.185 0 0 0 3.355 4.101 4.21 4.21 0 0 1-1.89.072A4.185 4.185 0 0 0 7.97 16.65a8.394 8.394 0 0 1-6.191 1.732 11.83 11.83 0 0 0 6.41 1.88c7.693 0 11.9-6.373 11.9-11.9 0-.18-.005-.362-.013-.54a8.496 8.496 0 0 0 2.087-2.165z' }))), props.attributes.social_ig && props.attributes.social_ig.url && el('a', { href: '#', 'aria-label': 'instagram', className: 'btn btn-outline-light lh-1 p-2 rounded-circle' }, el('svg', { viewBox: '0 0 24 24', fill: 'currentColor', width: '20', height: '20' }, el('path', { d: 'M12 2c2.717 0 3.056.01 4.122.06 1.065.05 1.79.217 2.428.465.66.254 1.216.598 1.772 1.153a4.908 4.908 0 0 1 1.153 1.772c.247.637.415 1.363.465 2.428.047 1.066.06 1.405.06 4.122 0 2.717-.01 3.056-.06 4.122-.05 1.065-.218 1.79-.465 2.428a4.883 4.883 0 0 1-1.153 1.772 4.915 4.915 0 0 1-1.772 1.153c-.637.247-1.363.415-2.428.465-1.066.047-1.405.06-4.122.06-2.717 0-3.056-.01-4.122-.06-1.065-.05-1.79-.218-2.428-.465a4.89 4.89 0 0 1-1.772-1.153 4.904 4.904 0 0 1-1.153-1.772c-.248-.637-.415-1.363-.465-2.428C2.013 15.056 2 14.717 2 12c0-2.717.01-3.056.06-4.122.05-1.066.217-1.79.465-2.428a4.88 4.88 0 0 1 1.153-1.772A4.897 4.897 0 0 1 5.45 2.525c.638-.248 1.362-.415 2.428-.465C8.944 2.013 9.283 2 12 2zm0 5a5 5 0 1 0 0 10 5 5 0 0 0 0-10zm6.5-.25a1.25 1.25 0 0 0-2.5 0 1.25 1.25 0 0 0 2.5 0zM12 9a3 3 0 1 1 0 6 3 3 0 0 1 0-6z' }))), props.attributes.social_ball && props.attributes.social_ball.url && el('a', { href: '#', 'aria-label': 'linkedin', className: 'btn btn-outline-light lh-1 p-2 rounded-circle' }, el('svg', { viewBox: '0 0 24 24', fill: 'currentColor', width: '20', height: '20' }, el('path', { d: 'M19.989 11.572a7.96 7.96 0 0 0-1.573-4.351 9.749 9.749 0 0 1-.92.87 13.157 13.157 0 0 1-3.313 2.01c.167.35.32.689.455 1.009v.003a9.186 9.186 0 0 1 .11.27c1.514-.17 3.11-.108 4.657.101.206.028.4.058.584.088zm-9.385-7.45a46.164 46.164 0 0 1 2.692 4.27c1.223-.482 2.234-1.09 3.048-1.767a7.88 7.88 0 0 0 .796-.755A7.968 7.968 0 0 0 12 4a8.05 8.05 0 0 0-1.396.121zM4.253 9.997a29.21 29.21 0 0 0 2.04-.123 31.53 31.53 0 0 0 4.862-.822 54.365 54.365 0 0 0-2.7-4.227 8.018 8.018 0 0 0-4.202 5.172zm1.53 7.038c.388-.567.898-1.205 1.575-1.899 1.454-1.49 3.17-2.65 5.156-3.29l.062-.018c-.165-.364-.32-.689-.476-.995-1.836.535-3.77.869-5.697 1.042-.94.085-1.783.122-2.403.128a7.967 7.967 0 0 0 1.784 5.032zm9.222 2.38a35.947 35.947 0 0 0-1.632-5.709c-2.002.727-3.597 1.79-4.83 3.058a9.77 9.77 0 0 0-1.317 1.655A7.964 7.964 0 0 0 12 20a7.977 7.977 0 0 0 3.005-.583zm1.873-1.075a7.998 7.998 0 0 0 2.987-4.87c-.34-.085-.771-.17-1.245-.236a12.023 12.023 0 0 0-3.18-.033 39.368 39.368 0 0 1 1.438 5.14zM12 22C6.477 22 2 17.523 2 12S6.477 2 12 2s10 4.477 10 10-4.477 10-10 10z' }))), props.attributes.social_behance && props.attributes.social_behance.url && el('a', { href: '#', 'aria-label': 'youtube', className: 'btn btn-outline-light lh-1 p-2 rounded-circle' }, el('svg', { viewBox: '0 0 24 24', fill: 'currentColor', width: '20', height: '20' }, el('path', { d: 'M7.443 5.35c.639 0 1.23.05 1.77.198a3.83 3.83 0 0 1 1.377.544c.394.247.689.594.885 1.039.197.445.295.99.295 1.583 0 .693-.147 1.286-.491 1.731-.295.446-.787.841-1.377 1.138.836.248 1.475.693 1.868 1.286.394.594.64 1.336.64 2.177 0 .693-.148 1.286-.394 1.781-.246.495-.639.94-1.082 1.237a5.078 5.078 0 0 1-1.573.692c-.59.149-1.18.248-1.77.248H1V5.35h6.443zm-.394 5.54c.541 0 .984-.148 1.328-.395.344-.247.492-.693.492-1.237 0-.297-.05-.594-.148-.791-.098-.198-.246-.347-.442-.495-.197-.099-.394-.198-.64-.247-.246-.05-.491-.05-.787-.05H4v3.216h3.05zm.148 5.838c.295 0 .59-.05.836-.099a1.72 1.72 0 0 0 .688-.297 1.76 1.76 0 0 0 .492-.544c.098-.247.197-.544.197-.89 0-.693-.197-1.188-.59-1.534-.394-.297-.935-.445-1.574-.445H4v3.81h3.197zm9.492-.05c.393.396.983.594 1.77.594.541 0 1.033-.148 1.426-.395.394-.297.64-.594.738-.891h2.41c-.394 1.187-.984 2.028-1.77 2.572-.788.495-1.722.792-2.853.792a5.753 5.753 0 0 1-2.115-.396 3.93 3.93 0 0 1-1.574-1.088 3.93 3.93 0 0 1-.983-1.633c-.246-.643-.345-1.335-.345-2.127 0-.742.099-1.434.345-2.078a5.34 5.34 0 0 1 1.032-1.682c.443-.445.984-.84 1.574-1.088a5.49 5.49 0 0 1 2.066-.396c.836 0 1.574.149 2.213.495.64.346 1.131.742 1.525 1.336a6.01 6.01 0 0 1 .885 1.88c.098.692.147 1.385.098 2.176H16c0 .792.295 1.534.689 1.93zm3.098-5.194c-.344-.346-.885-.544-1.525-.544-.442 0-.787.099-1.082.247-.295.149-.491.347-.688.545a1.322 1.322 0 0 0-.344.692c-.05.248-.099.445-.099.643h4.426c-.098-.742-.344-1.236-.688-1.583zM15.459 6.29h5.508v1.336H15.46V6.29z' })))])), el('div', { className: 'col-md col-sm-6' }, el(RichText, { tagName: 'a', href: '#', className: 'fs-5 link-light text-decoration-none', value: propOrDefault( props.attributes.phone, 'phone' ), onChange: function(val) { setAttributes( {phone: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] })), el('div', { className: 'col-md col-sm-6' }, el(RichText, { tagName: 'a', href: 'mailto:' + props.attributes.email, className: 'fs-5 link-light text-decoration-none', value: propOrDefault( props.attributes.email, 'email' ), onChange: function(val) { setAttributes( {email: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }))])])),                        
                
                    el( InspectorControls, {},
                        [
                            
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.cta,
                                        help: __( '' ),
                                        label: __( 'Call to action' ),
                                        onChange: function(val) { setAttributes({cta: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.description,
                                        help: __( '' ),
                                        label: __( 'Description' ),
                                        onChange: function(val) { setAttributes({description: val}) },
                                        type: 'text'
                                    }),
                                    pgUrlControl('button', setAttributes, props, 'Button link', '', null ),
                                    el(TextControl, {
                                        value: props.attributes.button_label,
                                        help: __( '' ),
                                        label: __( 'Button label' ),
                                        onChange: function(val) { setAttributes({button_label: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.site_name,
                                        help: __( '' ),
                                        label: __( 'Site name' ),
                                        onChange: function(val) { setAttributes({site_name: val}) },
                                        type: 'text'
                                    }),
                                    pgUrlControl('social_fb', setAttributes, props, 'Facebook', '', null ),
                                    pgUrlControl('social_twitter', setAttributes, props, 'Twitter', '', null ),
                                    pgUrlControl('social_ig', setAttributes, props, 'Instagram', '', null ),
                                    pgUrlControl('social_ball', setAttributes, props, 'Ball link', '', null ),
                                    pgUrlControl('social_behance', setAttributes, props, 'Behance', '', null ),
                                    el(TextControl, {
                                        value: props.attributes.phone,
                                        help: __( '' ),
                                        label: __( 'Phone' ),
                                        onChange: function(val) { setAttributes({phone: val}) },
                                        type: 'text'
                                    }),
                                    pgUrlControl('phone_link', setAttributes, props, 'Phone link', 'Use tel:1234567 format.', null ),
                                    el(TextControl, {
                                        value: props.attributes.email,
                                        help: __( '' ),
                                        label: __( 'Email address' ),
                                        onChange: function(val) { setAttributes({email: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'bg-dark pb-5 pt-5 text-white-50' });
            return el('footer', { ...blockProps }, el('div', { className: 'container' }, [el('div', { className: 'align-items-center gy-4 row' }, [el('div', { className: 'col-lg-8 col-md col-xl-6 me-auto' }, [el(RichText.Content, { tagName: 'h2', className: 'fw-bold h2 mb-3 text-capitalize text-white', value: propOrDefault( props.attributes.cta, 'cta' ) }), el(RichText.Content, { tagName: 'p', className: 'mb-0', value: propOrDefault( props.attributes.description, 'description' ) })]), el('div', { className: 'col-md-auto' }, props.attributes.button && props.attributes.button.url && el(RichText.Content, { tagName: 'a', href: props.attributes.button.url, className: 'btn btn-primary pb-2 pe-4 ps-4 pt-2', value: propOrDefault( props.attributes.button_label, 'button_label' ) }))]), el('hr', { className: 'border-secondary mb-5 mt-5' }), el('div', { className: 'align-items-center gy-3 row' }, [el('div', { className: 'col-lg-3 col-sm-6 col-xl-4' }, el('a', { className: 'd-inline-flex fw-bold h2 lh-1 link-primary mb-0 text-decoration-none text-uppercase', href: '#' }, el(RichText.Content, { tagName: 'span', value: propOrDefault( props.attributes.site_name, 'site_name' ) }))), el('div', { className: 'col-lg-auto col-sm-6 order-lg-last' }, el('div', { className: 'd-inline-flex flex-wrap gap-2' }, [props.attributes.social_fb && props.attributes.social_fb.url && el('a', { href: props.attributes.social_fb.url, 'aria-label': 'facebook', className: 'btn btn-outline-light lh-1 p-2 rounded-circle' }, el('svg', { viewBox: '0 0 24 24', fill: 'currentColor', width: '20', height: '20' }, el('path', { d: 'M14 13.5h2.5l1-4H14v-2c0-1.03 0-2 2-2h1.5V2.14c-.326-.043-1.557-.14-2.857-.14C11.928 2 10 3.657 10 6.7v2.8H7v4h3V22h4v-8.5z' }))), props.attributes.social_twitter && props.attributes.social_twitter.url && el('a', { href: props.attributes.social_twitter.url, 'aria-label': 'twitter', className: 'btn btn-outline-light lh-1 p-2 rounded-circle' }, el('svg', { viewBox: '0 0 24 24', fill: 'currentColor', width: '20', height: '20' }, el('path', { d: 'M22.162 5.656a8.384 8.384 0 0 1-2.402.658A4.196 4.196 0 0 0 21.6 4c-.82.488-1.719.83-2.656 1.015a4.182 4.182 0 0 0-7.126 3.814 11.874 11.874 0 0 1-8.62-4.37 4.168 4.168 0 0 0-.566 2.103c0 1.45.738 2.731 1.86 3.481a4.168 4.168 0 0 1-1.894-.523v.052a4.185 4.185 0 0 0 3.355 4.101 4.21 4.21 0 0 1-1.89.072A4.185 4.185 0 0 0 7.97 16.65a8.394 8.394 0 0 1-6.191 1.732 11.83 11.83 0 0 0 6.41 1.88c7.693 0 11.9-6.373 11.9-11.9 0-.18-.005-.362-.013-.54a8.496 8.496 0 0 0 2.087-2.165z' }))), props.attributes.social_ig && props.attributes.social_ig.url && el('a', { href: props.attributes.social_ig.url, 'aria-label': 'instagram', className: 'btn btn-outline-light lh-1 p-2 rounded-circle' }, el('svg', { viewBox: '0 0 24 24', fill: 'currentColor', width: '20', height: '20' }, el('path', { d: 'M12 2c2.717 0 3.056.01 4.122.06 1.065.05 1.79.217 2.428.465.66.254 1.216.598 1.772 1.153a4.908 4.908 0 0 1 1.153 1.772c.247.637.415 1.363.465 2.428.047 1.066.06 1.405.06 4.122 0 2.717-.01 3.056-.06 4.122-.05 1.065-.218 1.79-.465 2.428a4.883 4.883 0 0 1-1.153 1.772 4.915 4.915 0 0 1-1.772 1.153c-.637.247-1.363.415-2.428.465-1.066.047-1.405.06-4.122.06-2.717 0-3.056-.01-4.122-.06-1.065-.05-1.79-.218-2.428-.465a4.89 4.89 0 0 1-1.772-1.153 4.904 4.904 0 0 1-1.153-1.772c-.248-.637-.415-1.363-.465-2.428C2.013 15.056 2 14.717 2 12c0-2.717.01-3.056.06-4.122.05-1.066.217-1.79.465-2.428a4.88 4.88 0 0 1 1.153-1.772A4.897 4.897 0 0 1 5.45 2.525c.638-.248 1.362-.415 2.428-.465C8.944 2.013 9.283 2 12 2zm0 5a5 5 0 1 0 0 10 5 5 0 0 0 0-10zm6.5-.25a1.25 1.25 0 0 0-2.5 0 1.25 1.25 0 0 0 2.5 0zM12 9a3 3 0 1 1 0 6 3 3 0 0 1 0-6z' }))), props.attributes.social_ball && props.attributes.social_ball.url && el('a', { href: props.attributes.social_ball.url, 'aria-label': 'linkedin', className: 'btn btn-outline-light lh-1 p-2 rounded-circle' }, el('svg', { viewBox: '0 0 24 24', fill: 'currentColor', width: '20', height: '20' }, el('path', { d: 'M19.989 11.572a7.96 7.96 0 0 0-1.573-4.351 9.749 9.749 0 0 1-.92.87 13.157 13.157 0 0 1-3.313 2.01c.167.35.32.689.455 1.009v.003a9.186 9.186 0 0 1 .11.27c1.514-.17 3.11-.108 4.657.101.206.028.4.058.584.088zm-9.385-7.45a46.164 46.164 0 0 1 2.692 4.27c1.223-.482 2.234-1.09 3.048-1.767a7.88 7.88 0 0 0 .796-.755A7.968 7.968 0 0 0 12 4a8.05 8.05 0 0 0-1.396.121zM4.253 9.997a29.21 29.21 0 0 0 2.04-.123 31.53 31.53 0 0 0 4.862-.822 54.365 54.365 0 0 0-2.7-4.227 8.018 8.018 0 0 0-4.202 5.172zm1.53 7.038c.388-.567.898-1.205 1.575-1.899 1.454-1.49 3.17-2.65 5.156-3.29l.062-.018c-.165-.364-.32-.689-.476-.995-1.836.535-3.77.869-5.697 1.042-.94.085-1.783.122-2.403.128a7.967 7.967 0 0 0 1.784 5.032zm9.222 2.38a35.947 35.947 0 0 0-1.632-5.709c-2.002.727-3.597 1.79-4.83 3.058a9.77 9.77 0 0 0-1.317 1.655A7.964 7.964 0 0 0 12 20a7.977 7.977 0 0 0 3.005-.583zm1.873-1.075a7.998 7.998 0 0 0 2.987-4.87c-.34-.085-.771-.17-1.245-.236a12.023 12.023 0 0 0-3.18-.033 39.368 39.368 0 0 1 1.438 5.14zM12 22C6.477 22 2 17.523 2 12S6.477 2 12 2s10 4.477 10 10-4.477 10-10 10z' }))), props.attributes.social_behance && props.attributes.social_behance.url && el('a', { href: props.attributes.social_behance.url, 'aria-label': 'youtube', className: 'btn btn-outline-light lh-1 p-2 rounded-circle' }, el('svg', { viewBox: '0 0 24 24', fill: 'currentColor', width: '20', height: '20' }, el('path', { d: 'M7.443 5.35c.639 0 1.23.05 1.77.198a3.83 3.83 0 0 1 1.377.544c.394.247.689.594.885 1.039.197.445.295.99.295 1.583 0 .693-.147 1.286-.491 1.731-.295.446-.787.841-1.377 1.138.836.248 1.475.693 1.868 1.286.394.594.64 1.336.64 2.177 0 .693-.148 1.286-.394 1.781-.246.495-.639.94-1.082 1.237a5.078 5.078 0 0 1-1.573.692c-.59.149-1.18.248-1.77.248H1V5.35h6.443zm-.394 5.54c.541 0 .984-.148 1.328-.395.344-.247.492-.693.492-1.237 0-.297-.05-.594-.148-.791-.098-.198-.246-.347-.442-.495-.197-.099-.394-.198-.64-.247-.246-.05-.491-.05-.787-.05H4v3.216h3.05zm.148 5.838c.295 0 .59-.05.836-.099a1.72 1.72 0 0 0 .688-.297 1.76 1.76 0 0 0 .492-.544c.098-.247.197-.544.197-.89 0-.693-.197-1.188-.59-1.534-.394-.297-.935-.445-1.574-.445H4v3.81h3.197zm9.492-.05c.393.396.983.594 1.77.594.541 0 1.033-.148 1.426-.395.394-.297.64-.594.738-.891h2.41c-.394 1.187-.984 2.028-1.77 2.572-.788.495-1.722.792-2.853.792a5.753 5.753 0 0 1-2.115-.396 3.93 3.93 0 0 1-1.574-1.088 3.93 3.93 0 0 1-.983-1.633c-.246-.643-.345-1.335-.345-2.127 0-.742.099-1.434.345-2.078a5.34 5.34 0 0 1 1.032-1.682c.443-.445.984-.84 1.574-1.088a5.49 5.49 0 0 1 2.066-.396c.836 0 1.574.149 2.213.495.64.346 1.131.742 1.525 1.336a6.01 6.01 0 0 1 .885 1.88c.098.692.147 1.385.098 2.176H16c0 .792.295 1.534.689 1.93zm3.098-5.194c-.344-.346-.885-.544-1.525-.544-.442 0-.787.099-1.082.247-.295.149-.491.347-.688.545a1.322 1.322 0 0 0-.344.692c-.05.248-.099.445-.099.643h4.426c-.098-.742-.344-1.236-.688-1.583zM15.459 6.29h5.508v1.336H15.46V6.29z' })))])), el('div', { className: 'col-md col-sm-6' }, el(RichText.Content, { tagName: 'a', href: propOrDefault( props.attributes.phone_link.url, 'phone_link', 'url' ), className: 'fs-5 link-light text-decoration-none', value: propOrDefault( props.attributes.phone, 'phone' ) })), el('div', { className: 'col-md col-sm-6' }, el(RichText.Content, { tagName: 'a', href: 'mailto:' + props.attributes.email, className: 'fs-5 link-light text-decoration-none', value: propOrDefault( props.attributes.email, 'email' ) }))])]));
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
