
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'portfolio/project', {
        apiVersion: 2,
        title: 'Project',
        icon: 'block-default',
        category: 'pagesections',
        parent: [ 'portfolio/projects' ],

        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            pullup: {
                type: 'text',
                default: '',
            },
            link: {
                type: 'object',
                default: {post_id: 0, url: '#', title: '', 'post_type': null},
            },
            image: {
                type: 'object',
                default: {id: 0, url: 'https://images.unsplash.com/photo-1609921212029-bb5a28e60960?ixid=MnwyMDkyMnwwfDF8c2VhcmNofDUyfHxkZXNpZ25lcnxlbnwwfHx8fDE2MzI4Njk1ODY&ixlib=rb-1.2.1q=85&fm=jpg&crop=faces&cs=srgb&w=600&h=650&fit=crop', size: ''},
            },
            namr: {
                type: 'text',
                default: `Project 1`,
            },
            description: {
                type: 'text',
                default: `App Development`,
            }
        },
        example: { attributes: { pullup: '', link: {post_id: 0, url: '#', title: '', 'post_type': null}, image: {id: 0, url: 'https://images.unsplash.com/photo-1609921212029-bb5a28e60960?ixid=MnwyMDkyMnwwfDF8c2VhcmNofDUyfHxkZXNpZ25lcnxlbnwwfHx8fDE2MzI4Njk1ODY&ixlib=rb-1.2.1q=85&fm=jpg&crop=faces&cs=srgb&w=600&h=650&fit=crop', size: ''}, namr: `Project 1`, description: `App Development` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: propOrDefault( props.attributes.pullup, 'pullup' ) });
            const setAttributes = props.setAttributes; 
            
            props.image = useSelect(function( select ) {
                return {
                    image: props.attributes.image.id ? select('core').getMedia(props.attributes.image.id) : undefined
                };
            }, [props.attributes.image] ).image;
            
            const innerBlocksProps = null;
            
            
            return el(Fragment, {}, [
                el('div', { ...blockProps }, el('a', { href: '#', className: 'd-block link-dark text-decoration-none' }, [props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'img-fluid mb-4 rounded-1 shadow-sm w-100' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { src: propOrDefault( props.attributes.image.url, 'image', 'url' ), className: 'img-fluid mb-4 rounded-1 shadow-sm w-100', alt: '...', width: '600', height: '650' }), el(RichText, { tagName: 'h4', className: 'fw-bold h5 mb-1', value: propOrDefault( props.attributes.namr, 'namr' ), onChange: function(val) { setAttributes( {namr: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'p', className: 'mb-0', value: propOrDefault( props.attributes.description, 'description' ), onChange: function(val) { setAttributes( {description: val }) } })])),                        
                
                    el( InspectorControls, {},
                        [
                            
                        pgMediaImageControl('image', setAttributes, props, 'full', false ),
                                        
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(ToggleControl, {
                                        checked: props.attributes.pullup === 'mt-md-n5',
                                        label: __( 'Pull up' ),
                                        onChange: function(val) { setAttributes({pullup: val ? 'mt-md-n5' : null}) },
                                        help: __( '' ),
                                    }),
                                    pgUrlControl('link', setAttributes, props, 'Link', '', null ),
                                    el(TextControl, {
                                        value: props.attributes.namr,
                                        help: __( '' ),
                                        label: __( 'Name' ),
                                        onChange: function(val) { setAttributes({namr: val}) },
                                        type: 'text'
                                    }),
                                    el(BaseControl, {
                                        help: __( '' ),
                                        label: __( 'Description' ),
                                    }, [
                                        el(RichText, {
                                            value: props.attributes.description,
                                            style: {
                                                    border: '1px solid black',
                                                    padding: '6px 8px',
                                                    minHeight: '80px',
                                                    border: '1px solid rgb(117, 117, 117)',
                                                    fontSize: '13px',
                                                    lineHeight: 'normal'
                                                },
                                            onChange: function(val) { setAttributes({description: val}) },
                                        })
                                    ]),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: propOrDefault( props.attributes.pullup, 'pullup' ) });
            return el('div', { ...blockProps }, el('a', { href: propOrDefault( props.attributes.link.url, 'link', 'url' ), className: 'd-block link-dark text-decoration-none' }, [props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'img-fluid mb-4 rounded-1 shadow-sm w-100' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { src: propOrDefault( props.attributes.image.url, 'image', 'url' ), className: 'img-fluid mb-4 rounded-1 shadow-sm w-100', alt: '...', width: '600', height: '650' }), el(RichText.Content, { tagName: 'h4', className: 'fw-bold h5 mb-1', value: propOrDefault( props.attributes.namr, 'namr' ) }), el(RichText.Content, { tagName: 'p', className: 'mb-0', value: propOrDefault( props.attributes.description, 'description' ) })]));
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
